@@ -17,7 +17,7 @@
    limitations under the License.
 */
 
-/* $Id: rivetWWW.c 1716933 2015-11-27 23:54:35Z mxmanghi $ */
+/* $Id: rivetWWW.c 1716344 2015-11-25 10:05:50Z mxmanghi $ */
 
 /* Rivet config */
 #ifdef HAVE_CONFIG_H
@@ -350,6 +350,9 @@ TCL_CMD_HEADER( Rivet_EscapeShellCommandCmd )
  *   in safe interpreters, as they process strings only.
  *-----------------------------------------------------------------------------
  */
+#if RIVET_NAMESPACE_EXPORT == 1
+extern Tcl_Namespace* Rivet_GetNamespace( Tcl_Interp* interp);
+#endif
 
 int 
 Rivet_InitWWW( Tcl_Interp *interp)
@@ -358,5 +361,16 @@ Rivet_InitWWW( Tcl_Interp *interp)
     RIVET_OBJ_CMD ("escape_string",Rivet_EscapeStringCmd);
     RIVET_OBJ_CMD ("escape_sgml_chars",Rivet_EscapeSgmlCharsCmd);
     RIVET_OBJ_CMD ("escape_shell_command",Rivet_EscapeShellCommandCmd);
+
+#if RIVET_NAMESPACE_EXPORT == 1
+    {
+        Tcl_Namespace* rivet_ns = Rivet_GetNamespace(interp);
+
+        RIVET_EXPORT_CMD(interp,rivet_ns,"unescape_string");
+        RIVET_EXPORT_CMD(interp,rivet_ns,"escape_string");
+        RIVET_EXPORT_CMD(interp,rivet_ns,"escape_sgml_chars");
+        RIVET_EXPORT_CMD(interp,rivet_ns,"escape_shell_command");
+    }
+#endif
     return TCL_OK;
 }
