@@ -13,7 +13,7 @@
    limitations under the License.
 */
 
-/* $Id: rivet.h 1716933 2015-11-27 23:54:35Z mxmanghi $ */
+/* $Id: rivet.h 1716344 2015-11-25 10:05:50Z mxmanghi $ */
 
 /* This is for windows. */
 #ifdef BUILD_rivet
@@ -54,6 +54,10 @@ Tcl_CreateObjCommand( interp, /* Tcl interpreter */\
 		      NULL,   /* Client Data */\
 		      (Tcl_CmdDeleteProc *)NULL /* Tcl Delete Prov */); 
 
+#define RIVET_EXPORT_CMD(interp,ns,cmdname) Tcl_Export(interp,ns,cmdname,0);
+
+//Tcl_ListObjAppendElement(interp,export_l,Tcl_NewStringObj(RIVET_NS "::" cmdname,-1));
+
 /* 
  * Pointer in r is checked and in case Rivet_NoRequestRec is
  * called returning TCL_ERROR. This macro is used (and often
